numpy.ma.MaskType
=================

.. currentmodule:: numpy.ma

.. autoclass:: MaskType

   

   .. HACK
      .. autosummary::
         :toctree:
      
         MaskType.__init__
         MaskType.all
         MaskType.any
         MaskType.argmax
         MaskType.argmin
         MaskType.argsort
         MaskType.astype
         MaskType.byteswap
         MaskType.choose
         MaskType.clip
         MaskType.compress
         MaskType.conj
         MaskType.conjugate
         MaskType.copy
         MaskType.cumprod
         MaskType.cumsum
         MaskType.diagonal
         MaskType.dump
         MaskType.dumps
         MaskType.fill
         MaskType.flatten
         MaskType.getfield
         MaskType.item
         MaskType.itemset
         MaskType.max
         MaskType.mean
         MaskType.min
         MaskType.newbyteorder
         MaskType.nonzero
         MaskType.prod
         MaskType.ptp
         MaskType.put
         MaskType.ravel
         MaskType.repeat
         MaskType.reshape
         MaskType.resize
         MaskType.round
         MaskType.searchsorted
         MaskType.setfield
         MaskType.setflags
         MaskType.sort
         MaskType.squeeze
         MaskType.std
         MaskType.sum
         MaskType.swapaxes
         MaskType.take
         MaskType.tofile
         MaskType.tolist
         MaskType.tostring
         MaskType.trace
         MaskType.transpose
         MaskType.var
         MaskType.view



   

   .. HACK
      .. autosummary::
         :toctree:
      
         MaskType.T
         MaskType.base
         MaskType.data
         MaskType.dtype
         MaskType.flags
         MaskType.flat
         MaskType.imag
         MaskType.itemsize
         MaskType.nbytes
         MaskType.ndim
         MaskType.real
         MaskType.shape
         MaskType.size
         MaskType.strides

